@@ -13,8 +13,6 @@ def runtests():
     cfg_path = join(dirname(dirname(dirname(__file__))), 'setup.cfg')
 
     args = sys.argv[1:]
-    if not args or args[0].startswith('-'):
-        args += ['--pyargs', 'cykooz.testing']
     args = ['-c', cfg_path] + args
     environ['IS_TESTING'] = 'True'
     pytest.main(args)
